#' Set reports folder structure
#'
#' @param path Destination folder for reports and templates
#' @param overwrite Allow overwriting templates folder
#' @param git add gitignore file suitable for TeX and HTML reports
#'
#' @return The path to the created reports folder.
#' @export
#'
#' @examples
#' # Create structure for reports
#' path <- tempfile(pattern = "report-example")
#' dir.create(path)
#' create_reports(path, git = FALSE)
#' list.files(path, recursive = TRUE)
#'
#' # Add a new report
#' report_path <- add_report("my_report", path)
#' list.files(report_path)
create_reports <- function(path = ".", overwrite = FALSE, git = TRUE) {
  # Copy templates
  if (dir.exists(file.path(path, "templates"))) {
    if (overwrite) {
      warning("Folder ", file.path(path, "templates"), " is overwritten")
    } else {
      stop("Folder ", file.path(path, "templates"), " already exists")
    }
  }

  ok <- file.copy(
    from = pkg_sys("templates"),
    to = path,
    recursive = TRUE
  )
  if (!ok) stop("Error when copying 'templates' folder to ", path)

  # Create reports folder
  reports_path <- file.path(path, "reports")
  dir.create(reports_path, showWarnings = FALSE)
  if (git) {
    add_gitignore(
      reports_path,
      url = "https://raw.githubusercontent.com/github/gitignore/main/TeX.gitignore",
      additional_patterns = readLines(pkg_sys("reports_gitignore.txt"))
    )
  }
  invisible(file.path(path, "reports"))
}
